@@ -60,12 +60,32 @@ class AccMargin:
     update_time: datetime.datetime = None
 
 
-# 历史自己查询你
+# 入金历史信息
+@aztdataclass(proto.HisDeposit,
+              price_dec="amount_decimal_place",
+              adj_price=["deposit"],
+              adj_time=dict(settlement_date="%Y%m%d", deposit_time="%Y%m%d-%H:%M:%S.%f"),
+              )
+class HisDeposit:
+    settlement_date: datetime.datetime = None
+    account: str = None
+    client_ref: str = None
+    deposit: float = None
+    # deposit_time: datetime.datetime = None
+
+
+# 历史资金查询回报
 @aztdataclass(proto.QryHisAccAck, adj_repeat=["acc_margins"])
 class QryHisAccAck:
     acc_margins: [AccMargin] = None
 
 
+# 历史入金查询回报
+@aztdataclass(proto.QryHisDepositAck, adj_repeat=["his_deposits"])
+class QryHisDepositAck:
+    his_deposits: [HisDeposit] = None
+
+
 # 账户入金信息
 @aztdataclass(proto.AccDepositAck)
 class AccDepositAck:
@@ -73,6 +93,7 @@ class AccDepositAck:
     error_code: int = None
 
 
+# 委托订单执行状态
 @aztdataclass(proto.OrdStatusMsg, price_dec="price_decimal_place",
               adj_price=["traded_amount", "total_fee", "frozen_margin", "frozen_price"],
               adj_time=dict(report_time=["%Y%m%d-%H:%M:%S.%f", "%Y%m%d-%H%M%S.%f"]),
@@ -89,6 +110,7 @@ class OrdStatusMsg:
     report_time: datetime.datetime = None
 
 
+# 委托订单信息
 @aztdataclass(proto.OrdReport)
 class OrdReport:
     place_order: PlaceOrder = None
