@@ -1,3 +1,5 @@
+import datetime
+
 from .ve_api_old import *
 
 
@@ -46,6 +48,9 @@ class AztVeSpi:
     def onQueryHistoryAsset(self, msg):
         pass
 
+    def onQueryHistoryDeposit(self, msg):
+        pass
+
 
 class _SpiApdapter(CVexchangeTraderSpi):
     __new_spi = AztVeSpi()
@@ -95,6 +100,9 @@ class _SpiApdapter(CVexchangeTraderSpi):
     def onQueryHistoryAccReq(self, msg):
         self.__new_spi.onQueryHistoryAsset(msg)
 
+    def onQueryHistoryDepositReq(self, msg):
+        self.__new_spi.onQueryHistoryDeposit(msg)
+
 
 class AztVeApi:
 
@@ -131,6 +139,9 @@ class AztVeApi:
         logout_req = api_struct.LogoutReq(account=self.__account)
         self.__api.UserLogoutReq(logout_req)
 
+    def close_api(self):
+        return self.__api._close()
+
     # 查询账户信息
     def QueryAccountInfo(self, strategy_id: str = None, strategy_check_code: str = None, account: str = None,
                          passwd: str = None, sync: bool = False, timeout: int = None):
@@ -159,6 +170,10 @@ class AztVeApi:
         historyasset_req = api_struct.QryHisAccReq(account=self.__account, settlement_date=date)
         return self.__api.QueryHistoryAccReq(historyasset_req, sync, timeout)
 
+    def QueryHistoryDeposit(self, date: datetime.datetime = None, sync: bool = False, timeout: int = None):
+        historydeposit_req = api_struct.QryHisDepositReq(account=self.__account, settlement_date=date)
+        return self.__api.QueryHistoryDepositReq(historydeposit_req, sync, timeout)
+
     # 查询订单信息
     def QueryOrders(self, market: str = None, code: str = None, client_ref: str = None, order_id: str = None,
                     unfinished: bool = False, sync: bool = False, timeout: int = None):
