@@ -68,6 +68,8 @@ class CVexchangeTraderApi:
         # 设置zmq
         self.__context = zmq.Context()
         self.__socket = self.__context.socket(zmq.DEALER)
+        self.__poller = zmq.Poller()
+        self.__poller.register(self.__socket, zmq.POLLIN)
         # 设置接收线程
         self.__thread_report_recv = threading.Thread(target=self.__report_recv)
         self.__thread_report_recv.setDaemon(True)
@@ -76,22 +78,22 @@ class CVexchangeTraderApi:
         self.__thread_heart_beat.setDaemon(True)
         # 设置信号
         self._logined = False
+        self.__connected = False
         self.__closed = False
-        # 保存登录信息
-        # self._login_info = None
         # 同步管道
         self._queue_map = dict()
-        # # 设置client_ref标识
-        # self._client_ref = str(uuid.uuid4())
-        # 设置策略ID
+        # 设置账户标识
         self._sender_user = None
         # 心跳
         self._heart_beat_times = 3  # 心跳次数
         self._heart_beat_count = self._heart_beat_times  # 心跳倒数
         self._heart_beat_interval = 5  # 心跳间隔时间，5秒
         self._heart_beat_req = self.__init_heart_beat_req()  # 心跳请求
+        # zmq.poller检查超时时间
+        self.__poller_timeout = None  # 100毫秒
 
-    def Init(self, server_addr: str, spi=None, hb_times: int = None, hb_interval: int = None):
+    def Init(self, server_addr: str, spi=None, hb_times: int = None, hb_interval: int = None,
+             poller_timeout: int = None):
         # 设置服务器地址
         if not server_addr.startswith("tcp"):
             server_addr = f"tcp://{server_addr}"
@@ -107,19 +109,20 @@ class CVexchangeTraderApi:
             self._heart_beat_count = hb_times
         if hb_interval is not None and hb_interval >= 3:
             self._heart_beat_interval = hb_interval
+        self.__poller_timeout = poller_timeout  # 单位：毫秒
 
         # 连接服务器
         azt_logger.log(f"开始连接服务器 - {self._server_addr}")
         self.__socket.connect(self._server_addr)
         # 启动监听线程
         self.__thread_report_recv.start()
-
         # 发送心跳请求，确认服务器已连接
         # self.__queue_subscribe("heart_beat")  # 建立临时心跳接收队列
         self.__send_heart_beat()  # 发送一次心跳请求
         ret_heart_beat = self._queue_sync_get(name="heart_beat", timeout=self._heart_beat_interval)
         if ret_heart_beat is None:
             return azt_errors.ConnectedFailed(f"服务器 - {self._server_addr} - 连接失败！")
+        self.__connected = True
         azt_logger.log(f"已成功连接服务器 - {self._server_addr}!")
         # 开启心跳线程
         self.__thread_heart_beat.start()
@@ -130,71 +133,74 @@ class CVexchangeTraderApi:
 
     # ------ RegisterReq ------
     def RegisterReq(self, req_msg: MsgProto.RegisterReq):
-        self.__socket.send(self.__gen_unit_msg(req_msg, EnumProto.KVexchangeMsgID_RegisterReq))
+        self.__send(self.__gen_unit_msg(req_msg, EnumProto.KVexchangeMsgID_RegisterReq))
 
     # ------ LoginReq ------
     def UserLoginReq(self, req_msg: MsgProto.LoginReq):
-        self.__socket.send(self.__gen_unit_msg(req_msg, EnumProto.KVexchangeMsgID_LoginReq))
+        self.__send(self.__gen_unit_msg(req_msg, EnumProto.KVexchangeMsgID_LoginReq))
 
     # ------ LogoutReq ------
     def UserLogoutReq(self, req_msg: MsgProto.LogoutReq):
-        self.__socket.send(self.__gen_unit_msg(req_msg, EnumProto.KVexchangeMsgID_LogoutReq))
+        self.__send(self.__gen_unit_msg(req_msg, EnumProto.KVexchangeMsgID_LogoutReq))
 
     # ------ UserInfoQryReq ------
     def UserInfoQryReq(self, req_msg: MsgProto.UserInfoQryReq):
-        self.__socket.send(self.__gen_unit_msg(req_msg, EnumProto.KVexchangeMsgID_UserInfoQryReq))
+        self.__send(self.__gen_unit_msg(req_msg, EnumProto.KVexchangeMsgID_UserInfoQryReq))
 
     # ------ AccDepositReq ------
     def AccDepositReq(self, req_msg: MsgProto.AccDepositReq):
-        self.__socket.send(self.__gen_unit_msg(req_msg, EnumProto.KTradeReqType_AccDepositReq))
+        self.__send(self.__gen_unit_msg(req_msg, EnumProto.KTradeReqType_AccDepositReq))
 
     # ------ TradingAccQryReq ------
     def TradingAccQryReq(self, req_msg: MsgProto.TradingAccQryReq):
-        self.__socket.send(self.__gen_unit_msg(req_msg, EnumProto.KTradeReqType_TradingAccQryReq))
+        self.__send(self.__gen_unit_msg(req_msg, EnumProto.KTradeReqType_TradingAccQryReq))
 
     # ------ QueryOrdersReq ------
     def QueryOrdersReq(self, req_msg: MsgProto.QueryOrdersReq):
-        self.__socket.send(self.__gen_unit_msg(req_msg, EnumProto.KQueryOrdersReq))
+        self.__send(self.__gen_unit_msg(req_msg, EnumProto.KQueryOrdersReq))
 
     # ------ QueryTradesReq ------
     def QueryTradesReq(self, req_msg: MsgProto.QueryTradesReq):
-        self.__socket.send(self.__gen_unit_msg(req_msg, EnumProto.KQueryTradesReq))
+        self.__send(self.__gen_unit_msg(req_msg, EnumProto.KQueryTradesReq))
 
     # ------ QueryPositionsReq ------
     def QueryPositionsReq(self, req_msg: MsgProto.QueryPositionsReq):
-        self.__socket.send(self.__gen_unit_msg(req_msg, EnumProto.KQueryPositionsReq))
+        self.__send(self.__gen_unit_msg(req_msg, EnumProto.KQueryPositionsReq))
 
     # ------ QueryHistoryOrdersReq ------
     def QueryHistoryOrdersReq(self, req_msg: MsgProto.QueryHistoryOrdersReq):
-        self.__socket.send(self.__gen_unit_msg(req_msg, EnumProto.KQueryHistoryOrdersReq))
+        self.__send(self.__gen_unit_msg(req_msg, EnumProto.KQueryHistoryOrdersReq))
 
     # ------ QueryHistoryTradesReq ------
     def QueryHistoryTradesReq(self, req_msg: MsgProto.QueryHistoryTradesReq):
-        self.__socket.send(self.__gen_unit_msg(req_msg, EnumProto.KQueryHistoryTradesReq))
+        self.__send(self.__gen_unit_msg(req_msg, EnumProto.KQueryHistoryTradesReq))
 
     def QueryHistoryAccReq(self, req_msg: MsgProto.QryHisAccReq):
-        self.__socket.send(self.__gen_unit_msg(req_msg, EnumProto.KTradeReqType_QryHisAccReq))
+        self.__send(self.__gen_unit_msg(req_msg, EnumProto.KTradeReqType_QryHisAccReq))
 
     def QueryHistoryDepositReq(self, req_msg: MsgProto.QryHisDepositReq):
-        self.__socket.send(self.__gen_unit_msg(req_msg, EnumProto.KTradeReqType_QryHisDepositReq))
+        self.__send(self.__gen_unit_msg(req_msg, EnumProto.KTradeReqType_QryHisDepositReq))
 
     # ------ PlaceOrder ------
     def PlaceOrder(self, req_msg: MsgProto.PlaceOrder):
-        self.__socket.send(self.__gen_unit_msg(req_msg, EnumProto.KTradeReqType_PlaceOrder))
+        self.__send(self.__gen_unit_msg(req_msg, EnumProto.KTradeReqType_PlaceOrder))
 
     # ------ CancelOrder ------
     def CancelOrder(self, req_msg: MsgProto.CancelOrder):
-        self.__socket.send(self.__gen_unit_msg(req_msg, EnumProto.KTradeReqType_CancelOrder))
+        self.__send(self.__gen_unit_msg(req_msg, EnumProto.KTradeReqType_CancelOrder))
 
     def _close(self):
-        self.__closed = True
-        try:
-            self.__socket.close()
-            self.__context.destroy()
-        except KeyboardInterrupt:
-            exit(1)
-        except Exception as e:
-            return e
+        if not self.__closed:
+            self.__closed = True
+            try:
+                self.__poller.unregister(self.__socket)
+                self.__socket.disconnect(self._server_addr)
+                self.__socket.close()
+                if self.__connected:
+                    self.__context.destroy()
+                del self.__context
+            except Exception as e:
+                return e
 
     @staticmethod
     def _gen_client_ref():
@@ -239,47 +245,55 @@ class CVexchangeTraderApi:
             # azt_logger.debug("注销回调：", spi_name)
 
     def __send_heart_beat(self):
-        self.__socket.send(self._heart_beat_req.SerializeToString())
+        self.__send(self._heart_beat_req.SerializeToString())
+
+    def __send(self, msg):
+        if not self.__closed:
+            self.__socket.send(msg)
 
     def __heart_beat(self):
         azt_logger.log("心跳线程启动成功！")
         time.sleep(self._heart_beat_interval)
-        while self._heart_beat_count > 0:
+
+        while self._heart_beat_count > 0 and not self.__closed:
+            # if self._heart_beat_count <= 0 or self.__closed:
+            #     break
+            if self._heart_beat_count < self._heart_beat_times:
+                azt_logger.warning(
+                    f"心跳接收异常！正在确认心跳...{self._heart_beat_times - self._heart_beat_count}")
             self._heart_beat_count -= 1
             self.__send_heart_beat()
             time.sleep(self._heart_beat_interval)
-            if self._heart_beat_count < self._heart_beat_times:
-                azt_logger.warning(
-                    f"心跳接收异常！正在确认心跳...{self._heart_beat_times - self._heart_beat_count + 1}")
-        # if not self.__closed:
+        if not self.__closed:
+            azt_logger.error("与服务器连接已中断！")
+            err = self._close()
+            if err:
+                raise err
 
-        azt_logger.error("与服务器连接已中断！")
-        err = self._close()
-        if err:
-            raise err
-        # raise azt_errors.ConnectedBroken
-
-    def __report_recv(self):  # 加__作为私有方法
-        poller = zmq.Poller()
-        poller.register(self.__socket, zmq.POLLIN)
-        while True:
+    def __recv(self):
+        while not self.__closed:
             try:
-                events = poller.poll()  # poll模式是用于多个socket场景的,可以避免某个socket的接收阻塞问题,这里用不用都行
+                events = self.__poller.poll(timeout=self.__poller_timeout)
             except zmq.error.ZMQError as zmqerror:
                 if self.__closed:
                     break
                 raise zmqerror
             except Exception as e:
                 raise e
-
             if self.__socket in dict(events):
-                recv_msg = self.__socket.recv()
-                unit_msg = UnitMsgProto.UnitedMessage()
-                unit_msg.ParseFromString(recv_msg)
-                self.__report_handel(unit_msg)
+                return self.__socket.recv(flags=zmq.NOBLOCK)
+
+    def __report_recv(self):  # 加__作为私有方法
+        while True:
+            recv_msg = self.__recv()
+            if recv_msg is None:
+                break
+            unit_msg = UnitMsgProto.UnitedMessage()
+            unit_msg.ParseFromString(recv_msg)
+            self.__report_handel(unit_msg)
 
     def __report_handel(self, unit_msg):
-        azt_logger.debug(f"收到消息：{unit_msg.msg_type}-{unit_msg.msg_id}")
+        # azt_logger.debug(f"收到消息：{unit_msg.msg_type}-{unit_msg.msg_id}")
         if unit_msg.msg_type != MsgTypeProto.KMsgType_Exchange_Rsp:
             return
 
